@@ -92,14 +92,14 @@ tar_combine_impl <- function(
   retrieval,
   cue
 ) {
-  assert_chr(name)
-  assert_targets(targets)
+  targets::tar_assert_chr(name)
+  targets::tar_assert_target_list(targets)
   names_chr <- map_chr(targets, ~.x$settings$name)
   names_sym <- as_symbols(names_chr)
   if (use_names) {
     names(names_sym) <- names_chr
   }
-  command <- tar_tidy_eval(
+  command <- targets::tar_tidy_eval(
     command,
     envir = list(.x = names_sym),
     tidy_eval = TRUE
